FlushCallback

Type Alias FlushCallback 

pub type FlushCallback = Box<dyn Fn(&str, RecordBatch) + Send>;
Callback function type for flushing RecordBatches. Takes ownership of the RecordBatch. The callback should handle empty batches by creating the table with the schema but not appending the empty data.

Aliased Type

pub struct FlushCallback(/* private fields */);